@@ -4,6 +4,7 @@ import warnings
 
 import numpy as np
 from astropy import units as u
+from astropy.nddata import StdDevUncertainty
 from astropy.modeling import fitting, Model, models
 from astropy.table import QTable
 from scipy.signal import convolve
@@ -102,7 +103,8 @@ def _consecutive(data, stepsize=1):
 def find_lines_threshold(spectrum, noise_factor=1):
     """
     Find the emission and absorption lines in a spectrum. The method
-    here is based on deviations larger than the spectrum's uncertainty by the
+    here is based on deviations larger than the spectrum's uncertainty
+    (converted to standard deviation if in another representation) by the
     ``noise_factor``.
 
     This method only works with continuum-subtracted spectra and the
@@ -129,7 +131,7 @@ def find_lines_threshold(spectrum, noise_factor=1):
 
     # Threshold based on noise estimate and factor.
     uncertainty = spectrum.uncertainty
-    uncert_val = 0 if uncertainty is None else uncertainty.array
+    uncert_val = 0 if uncertainty is None else uncertainty.represent_as(StdDevUncertainty).array
 
     inds = np.where(np.abs(spectrum.flux) > (noise_factor * uncert_val) *
                     spectrum.flux.unit)[0]
@@ -382,14 +384,15 @@ def _fit_lines(spectrum, model, fitter=fitting.LevMarLSQFitter(calc_uncertaintie
 
     if isinstance(weights, str):
         if weights == 'unc':
-            uncerts = spectrum.uncertainty
-
-            # Astropy fitters expect weights in 1/sigma
-            if uncerts is not None:
+            if spectrum.uncertainty is not None:
+                # Convert uncertainty to StdDev, then invert
+                uncerts = spectrum.uncertainty.represent_as(StdDevUncertainty)
+                # Astropy fitters expect weights in 1/sigma
                 weights = uncerts.array ** -1
             else:
-                warnings.warn("Uncertainty values are not defined, but are "
-                              "trying to be used in model fitting.")
+                weights = None
+                warnings.warn("Fitting is set to use uncertainties as weights,"
+                              " but the input spectrum's uncertainty is None")
         else:
             raise ValueError("Unrecognized value `%s` in keyword argument.",
                              weights)
