@@ -1,6 +1,3 @@
-import os
-import _io
-
 import numpy as np
 
 from astropy.io import fits
