@@ -14,7 +14,7 @@ def test_apStar_loader(tmpdir):
                   "stars/apo25m/N7789/apStar-r12-2M00005414+5522241.fits")
     with set_temp_cache(path=str(tmpdir)):
         filename = download_file(apstar_url, cache=True)
-        spectrum = apStar_loader(filename)
+        spectrum = apStar_loader(filename)  # noqa
 
 
 @pytest.mark.remote_data
@@ -24,7 +24,7 @@ def test_apVisit_loader(tmpdir):
                    "apVisit-r12-5094-55874-123.fits")
     with set_temp_cache(path=str(tmpdir)):
         filename = download_file(apvisit_url, cache=True)
-        spectrum = apVisit_loader(filename)
+        spectrum = apVisit_loader(filename)  # noqa
 
 
 @pytest.mark.remote_data
@@ -33,4 +33,4 @@ def test_aspcapStar_loader(tmpdir):
                   "l33/apo25m/N7789/aspcapStar-r12-2M00005414+5522241.fits")
     with set_temp_cache(path=str(tmpdir)):
         filename = download_file(aspcap_url, cache=True)
-        spectrum = aspcapStar_loader(filename)
+        spectrum = aspcapStar_loader(filename)  # noqa
