@@ -4,6 +4,6 @@ The core specutils data objects package. This contains the
 """
 from .spectrum1d import *  # noqa
 from .spectral_region import *  # noqa
-from .spectrum_collection import *  #noqa
-from .spectrum_list import * #noqa
-from .spectral_coordinate import *
+from .spectrum_collection import *  # noqa
+from .spectrum_list import * # noqa
+from .spectral_axis import *  # noqa
