@@ -101,6 +101,7 @@ def test_equivalent_width():
     result = equivalent_width(spectrum)
 
     assert result.unit.is_equivalent(spectrum.wcs.unit, equivalencies=u.spectral())
+    assert hasattr(result, 'uncertainty')
 
     # Since this is an emission line, we expect the equivalent width value to
     # be negative
@@ -467,6 +468,9 @@ def test_centroid(simulated_spectra):
 
     assert isinstance(spec_centroid, u.Quantity)
     assert np.allclose(spec_centroid.value, spec_centroid_expected.value)
+    assert hasattr(spec_centroid, 'uncertainty')
+    # NOTE: value has not been scientifically validated
+    assert quantity_allclose(spec_centroid.uncertainty, 3.91834165e-06*u.um, rtol=5e-5)
 
 
 def test_centroid_masked(simulated_spectra):
@@ -493,6 +497,9 @@ def test_centroid_masked(simulated_spectra):
 
     assert isinstance(spec_centroid, u.Quantity)
     assert np.allclose(spec_centroid.value, spec_centroid_expected.value)
+    assert hasattr(spec_centroid, 'uncertainty')
+    # NOTE: value has not been scientifically validated
+    assert quantity_allclose(spec_centroid.uncertainty, 1.1052437538307923e-05*u.um, rtol=5e-5)
 
 
 def test_inverted_centroid(simulated_spectra):
@@ -539,13 +546,19 @@ def test_centroid_multiple_flux(simulated_spectra):
 
     np.random.seed(42)
 
-    spec = Spectrum1D(spectral_axis=np.arange(10) * u.um,
+    spec = Spectrum1D(spectral_axis=np.arange(1, 11) * u.um,
                       flux=np.random.sample((5, 10)) * u.Jy)
+    uncertainty = StdDevUncertainty(0.1*np.random.random(spec.flux.shape)*u.mJy)
+    spec.uncertainty = uncertainty
 
     centroid_spec = centroid(spec, None)
 
-    assert np.allclose(centroid_spec.value, np.array([4.46190995, 4.17223565, 4.37778249, 4.51595259, 4.7429066]))
+    assert np.allclose(centroid_spec.value, np.array([5.46190995, 5.17223565, 5.37778249, 5.51595259, 5.7429066]))
     assert centroid_spec.unit == u.um
+    assert hasattr(centroid_spec, 'uncertainty')
+    assert len(centroid_spec.uncertainty) == 5
+    # NOTE: value has not been scientifically validated
+    assert np.allclose(centroid_spec.uncertainty.value, np.array([0.2812655, 0.39435469, 0.3286723, 0.31117068, 0.30481023]))
 
 
 def test_gaussian_sigma_width():
@@ -554,14 +567,19 @@ def test_gaussian_sigma_width():
 
     # Create a (centered) gaussian spectrum for testing
     mean = 5
-    frequencies = np.linspace(0, mean*2, 100) * u.GHz
+    frequencies = np.linspace(0, mean*2, 101)[1:] * u.GHz
     g1 = models.Gaussian1D(amplitude=5*u.Jy, mean=mean*u.GHz, stddev=0.8*u.GHz)
 
     spectrum = Spectrum1D(spectral_axis=frequencies, flux=g1(frequencies))
+    uncertainty = StdDevUncertainty(0.1*np.random.random(len(spectrum.flux))*u.mJy)
+    spectrum.uncertainty = uncertainty
 
     result = gaussian_sigma_width(spectrum)
 
     assert quantity_allclose(result, g1.stddev, atol=0.01*u.GHz)
+    assert hasattr(result, 'uncertainty')
+    # NOTE: value has not been scientifically validated!
+    assert quantity_allclose(result.uncertainty, 4.8190546890398186e-05*u.GHz, rtol=5e-5)
 
 
 def test_gaussian_sigma_width_masked():
@@ -570,7 +588,7 @@ def test_gaussian_sigma_width_masked():
 
     # Create a (centered) gaussian masked spectrum for testing
     mean = 5
-    frequencies = np.linspace(0, mean*2, 100) * u.GHz
+    frequencies = np.linspace(0, mean*2, 101)[1:] * u.GHz
     g1 = models.Gaussian1D(amplitude=5*u.Jy, mean=mean*u.GHz, stddev=0.8*u.GHz)
     uncertainty = StdDevUncertainty(0.1*np.random.random(len(frequencies))*u.Jy)
 
@@ -582,13 +600,16 @@ def test_gaussian_sigma_width_masked():
     result = gaussian_sigma_width(spectrum)
 
     assert quantity_allclose(result, g1.stddev, atol=0.01*u.GHz)
+    assert hasattr(result, 'uncertainty')
+    # NOTE: value has not been scientifically validated!
+    assert quantity_allclose(result.uncertainty, 0.06852821940808544*u.GHz, rtol=5e-5)
 
 
 def test_gaussian_sigma_width_regions():
 
     np.random.seed(42)
 
-    frequencies = np.linspace(100, 0, 10000) * u.GHz
+    frequencies = np.linspace(100, 0, 10000)[:-1] * u.GHz
     g1 = models.Gaussian1D(amplitude=5*u.Jy, mean=10*u.GHz, stddev=0.8*u.GHz)
     g2 = models.Gaussian1D(amplitude=5*u.Jy, mean=2*u.GHz, stddev=0.3*u.GHz)
     g3 = models.Gaussian1D(amplitude=5*u.Jy, mean=70*u.GHz, stddev=10*u.GHz)
@@ -651,15 +672,20 @@ def test_gaussian_fwhm():
 
     # Create a (centered) gaussian spectrum for testing
     mean = 5
-    frequencies = np.linspace(0, mean*2, 100) * u.GHz
+    frequencies = np.linspace(0, mean*2, 101)[1:] * u.GHz
     g1 = models.Gaussian1D(amplitude=5*u.Jy, mean=mean*u.GHz, stddev=0.8*u.GHz)
 
     spectrum = Spectrum1D(spectral_axis=frequencies, flux=g1(frequencies))
+    uncertainty = StdDevUncertainty(0.1*np.random.random(len(spectrum.flux))*u.mJy)
+    spectrum.uncertainty = uncertainty
 
     result = gaussian_fwhm(spectrum)
 
     expected = g1.stddev * gaussian_sigma_to_fwhm
     assert quantity_allclose(result, expected, atol=0.01*u.GHz)
+    assert hasattr(result, 'uncertainty')
+    # NOTE: value has not been scientifically validated!
+    assert quantity_allclose(result.uncertainty, 0.00011348006579851353*u.GHz, rtol=5e-5)
 
 
 def test_gaussian_fwhm_masked():
@@ -681,6 +707,9 @@ def test_gaussian_fwhm_masked():
 
     expected = g1.stddev * gaussian_sigma_to_fwhm
     assert quantity_allclose(result, expected, atol=0.01*u.GHz)
+    assert hasattr(result, 'uncertainty')
+    # NOTE: value has not been scientifically validated!
+    assert quantity_allclose(result.uncertainty, 0.16688079501948674*u.GHz, rtol=5e-5)
 
 
 @pytest.mark.parametrize('mean', range(3, 8))
@@ -792,7 +821,6 @@ def test_fwhm():
 
     spectrum = Spectrum1D(spectral_axis=wavelengths, flux=flux)
     result = fwhm(spectrum)
-
     assert quantity_allclose(result, 1.01 * u.um)
 
     # Highest point at the last point
@@ -1013,12 +1041,10 @@ def test_moment_cube():
     assert quantity_allclose(moment_1, frequencies, rtol=1.E-5)
 
     # higher order
-    # FIXME: operands could not be broadcast together with shapes (9,10,10000) (10,9,10000)
-    with pytest.raises(ValueError, match='operands could not be broadcast together'):
-        moment_2 = moment(spectrum, order=2)
-        assert moment_2.shape == (9, 10)
-        assert moment_2.unit.is_equivalent(u.GHz**2)
-        assert quantity_allclose(moment_2, 816.648*u.GHz**2, atol=0.01*u.GHz**2)
+    moment_2 = moment(spectrum, order=2)
+    assert moment_2.shape == (9, 10)
+    assert moment_2.unit.is_equivalent(u.GHz**2)
+    assert quantity_allclose(moment_2, 816.648*u.GHz**2, atol=0.01*u.GHz**2)
 
 
 def test_moment_cube_order_2():
@@ -1045,6 +1071,10 @@ def test_moment_cube_order_2():
     assert moment_2.unit.is_equivalent(u.GHz**2)
     assert quantity_allclose(moment_2, 816.648*u.GHz**2, atol=0.01*u.GHz**2)
 
+    # TODO: Remove test completely if it is agreed it is no longer needed
+    # Github issue https://github.com/astropy/specutils/issues/930
+    # mentions that removing ability to set axis makes this test invalid
+
     # spatial higher order (what's the meaning of this?)
     moment_2 = moment(spectrum, order=2, axis=1)
 
@@ -1053,7 +1083,54 @@ def test_moment_cube_order_2():
     # check assorted values.
     assert quantity_allclose(moment_2[0][0], 2.019e-28*u.GHz**2, rtol=0.01)
     assert quantity_allclose(moment_2[1][0], 2.019e-28*u.GHz**2, rtol=0.01)
-    assert quantity_allclose(moment_2[0][3], 8.078e-28*u.GHz**2, rtol=0.01)
+    assert quantity_allclose(moment_2[0][3], 2.019e-28*u.GHz**2, rtol=0.01)
+
+
+def test_moment_cube_order_1_to_6():
+
+    np.random.seed(42)
+
+    frequencies = np.linspace(100, 1, 10000) * u.Hz
+    sig = 5
+    mean = 50
+    amp = 1./(sig*np.sqrt(2*np.pi))
+    g = models.Gaussian1D(amplitude=amp, mean=mean*u.Hz, stddev=sig*u.Hz)
+    flux = g(frequencies)
+
+    flux_multid = np.broadcast_to(flux, [9, 10, flux.shape[0]]) * u.Jy
+
+    spectrum = Spectrum1D(spectral_axis=frequencies, flux=flux_multid)
+
+    moment_1 = moment(spectrum, order=1)
+
+    assert moment_1.shape == (9, 10)
+    assert moment_1.unit.is_equivalent(u.Hz)
+    assert quantity_allclose(moment_1, 50.0*u.Hz, atol=0.01*u.Hz)
+
+    moment_2 = moment(spectrum, order=2)
+    assert moment_2.shape == (9, 10)
+    assert moment_2.unit.is_equivalent(u.Hz**2)
+    assert quantity_allclose(moment_2, 25.0*u.Hz**2, atol=0.01*u.Hz**2)
+
+    moment_3 = moment(spectrum, order=3)
+    assert moment_3.shape == (9, 10)
+    assert moment_3.unit.is_equivalent(u.Hz**3)
+    assert quantity_allclose(moment_3, 0.0*u.Hz**3, atol=0.01*u.Hz**3)
+
+    moment_4 = moment(spectrum, order=4)
+    assert moment_4.shape == (9, 10)
+    assert moment_4.unit.is_equivalent(u.Hz**4)
+    assert quantity_allclose(moment_4, 1875.0*u.Hz**4, atol=0.01*u.Hz**4)
+
+    moment_5 = moment(spectrum, order=5)
+    assert moment_5.shape == (9, 10)
+    assert moment_5.unit.is_equivalent(u.Hz**5)
+    assert quantity_allclose(moment_5, 0.0*u.Hz**5, atol=0.01*u.Hz**5)
+
+    moment_6 = moment(spectrum, order=6)
+    assert moment_6.shape == (9, 10)
+    assert moment_6.unit.is_equivalent(u.Hz**6)
+    assert quantity_allclose(moment_6, 234375.0*u.Hz**6, atol=0.01*u.Hz**6)
 
 
 @pytest.mark.filterwarnings('ignore:Not all spectra have associated uncertainties of the same type')
